@@ -4,7 +4,7 @@
  * Gnome Crystal
  * atomsdlg.cc 
  *
- * Copyright (C) 2002-2004
+ * Copyright (C) 2002-2005
  *
  * Developed by Jean Bréfort <jean.brefort@normalesup.org>
  *
@@ -410,7 +410,7 @@ void gcAtomsDlg::OnEdited(GtkCellRendererText *cell, const gchar *path_string, c
 
 	gtk_tree_model_get_iter (GTK_TREE_MODEL(AtomList), &iter, path);
 
-	gint i = gtk_tree_path_get_indices (path)[0], j  = (int)g_object_get_data (G_OBJECT (cell), "column");
+	gint i = gtk_tree_path_get_indices (path)[0], j  = (long)g_object_get_data (G_OBJECT (cell), "column");
 	double x = atof(new_text);
 	gtk_list_store_set(AtomList, &iter, j, x, -1);
 	switch (j)
