@@ -4,9 +4,9 @@
  * Gnome Crystal
  * sizedlg.cc 
  *
- * Copyright (C) 2002-2004
+ * Copyright (C) 2002-2005
  *
- * Developed by Jean Bréfort <jean.brefort@ac-dijon.fr>
+ * Developed by Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -27,6 +27,7 @@
 #include "config.h"
 #include "celldlg.h"
 #include "document.h"
+#include "globals.h"
 
 void on_type_changed(GtkWidget* w, gcCellDlg *pBox)
 {
@@ -137,6 +138,7 @@ bool gcCellDlg::Apply()
 	{
 		GtkDialog* box = GTK_DIALOG(gtk_message_dialog_new(GTK_WINDOW(dialog), GTK_DIALOG_MODAL,
 										GTK_MESSAGE_ERROR, GTK_BUTTONS_OK, _("The sum of the three angles must be less than 360")));
+		SET_ICON(box);
 		gtk_dialog_run(box);
 	}
 	m_pDoc->SetCell(i, m_a, m_b, m_c, m_alpha, m_beta, m_gamma);
